"""Deprecated - use the monitors package rather than psychopy.calib
"""
# Part of the PsychoPy library
# Copyright (C) 2012 Jonathan Peirce
# Distributed under the terms of the GNU General Public License (GPL).

from psychopy import logging
logging.warning("psychopy.calib is deprecated - use monitors package instead")
from monitors import *
